@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_APP_GLOBAL_OBJECT_H_
-#define _U2_APP_GLOBAL_OBJECT_H_
+#pragma once
 
 #include <QObject>
 
@@ -39,9 +38,9 @@ class U2CORE_EXPORT AppGlobalObject : public QObject, public Identifiable<QStrin
     Q_OBJECT
 
 public:
-    AppGlobalObject(const QString& id) : Identifiable<QString>(id) {}
+    AppGlobalObject(const QString& id)
+        : Identifiable<QString>(id) {
+    }
 };
 
-} //namespace
-
-#endif
+}  // namespace U2
