@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,6 +19,8 @@
  * MA 02110-1301, USA.
  */
 
+#include "CreateAnnotationNormalWidget.h"
+
 #include <QMenu>
 
 #include <U2Core/Counter.h>
@@ -27,13 +29,10 @@
 #include <U2Gui/SaveDocumentController.h>
 #include <U2Gui/ShowHideSubgroupWidget.h>
 
-#include "CreateAnnotationNormalWidget.h"
-
 namespace U2 {
 
-CreateAnnotationNormalWidget::CreateAnnotationNormalWidget(QWidget *parent) :
-    CreateAnnotationWidget(parent)
-{
+CreateAnnotationNormalWidget::CreateAnnotationNormalWidget(QWidget* parent)
+    : CreateAnnotationWidget(parent) {
     setupUi(this);
     initLayout();
     init();
@@ -114,32 +113,32 @@ void CreateAnnotationNormalWidget::focusLocation() {
     leLocation->setFocus();
 }
 
-void CreateAnnotationNormalWidget::setNewTablePath(const QString &path) {
+void CreateAnnotationNormalWidget::setNewTablePath(const QString& path) {
     leNewTablePath->setText(path);
 }
 
-void CreateAnnotationNormalWidget::setGroupName(const QString &name) {
+void CreateAnnotationNormalWidget::setGroupName(const QString& name) {
     leGroupName->setText(name);
 }
 
 void CreateAnnotationNormalWidget::setAnnotationType(U2FeatureType type) {
     int index = cbAnnotationType->findText(U2FeatureTypes::getVisualName(type));
     if (Q_UNLIKELY(index == -1)) {
-        Q_ASSERT(false);    // an incorrect type
+        Q_ASSERT(false);  // an incorrect type
         index = cbAnnotationType->findText(U2FeatureTypes::getVisualName(U2FeatureTypes::MiscFeature));
     }
     cbAnnotationType->setCurrentIndex(index);
 }
 
-void CreateAnnotationNormalWidget::setAnnotationName(const QString &name) {
+void CreateAnnotationNormalWidget::setAnnotationName(const QString& name) {
     leAnnotationName->setText(name);
 }
 
-void CreateAnnotationNormalWidget::setLocation(const U2Location &location) {
+void CreateAnnotationNormalWidget::setLocation(const U2Location& location) {
     leLocation->setText(getGenbankLocationString(location));
 }
 
-void CreateAnnotationNormalWidget::setDescription(const QString &description) {
+void CreateAnnotationNormalWidget::setDescription(const QString& description) {
     leDescription->setText(description);
 }
 
@@ -198,28 +197,28 @@ bool CreateAnnotationNormalWidget::isAutoTableOptionSelected() const {
     return rbUseAutoTable->isChecked();
 }
 
-void CreateAnnotationNormalWidget::showSelectGroupMenu(QMenu &menu) {
+void CreateAnnotationNormalWidget::showSelectGroupMenu(QMenu& menu) {
     const QPoint menuPos = tbSelectGroupName->mapToGlobal(tbSelectGroupName->rect().bottomLeft());
     menu.exec(menuPos);
 }
 
-GObjectComboBoxController *CreateAnnotationNormalWidget::createGObjectComboBoxController(const GObjectComboBoxControllerConstraints &constraints) {
+GObjectComboBoxController* CreateAnnotationNormalWidget::createGObjectComboBoxController(const GObjectComboBoxControllerConstraints& constraints) {
     return new GObjectComboBoxController(this, constraints, cbExistingTable);
 }
 
 void CreateAnnotationNormalWidget::countDescriptionUsage() const {
     if (!leDescription->text().isEmpty()) {
-        GCOUNTER(cvar, tvar, "CreateAnnotationNormalWidget: description is used");
+        GCOUNTER(cvar, "CreateAnnotationNormalWidget: description is used");
     }
 }
 
-void CreateAnnotationNormalWidget::fillSaveDocumentControllerConfig(SaveDocumentControllerConfig &config) const {
+void CreateAnnotationNormalWidget::fillSaveDocumentControllerConfig(SaveDocumentControllerConfig& config) const {
     config.fileNameEdit = leNewTablePath;
     config.fileDialogButton = tbBrowseNewTable;
 }
 
 void CreateAnnotationNormalWidget::initLayout() {
-    ShowHideSubgroupWidget *saveShowHideWidget = new ShowHideSubgroupWidget("save_params", tr("Save annotation(s) to"), saveAnnotationsInnerWidget, true);
+    ShowHideSubgroupWidget* saveShowHideWidget = new ShowHideSubgroupWidget("save_params", tr("Save annotation(s) to"), saveAnnotationsInnerWidget, true);
     saveShowHideWidget->setPermanentlyOpen(true);
     mainLayout->insertWidget(0, saveShowHideWidget);
 
@@ -236,11 +235,11 @@ void CreateAnnotationNormalWidget::connectSignals() {
     connect(tbBrowseExistingTable, SIGNAL(clicked()), SIGNAL(si_selectExistingTableRequest()));
     connect(tbSelectGroupName, SIGNAL(clicked()), SIGNAL(si_selectGroupNameMenuRequest()));
     connect(tbDoComplement, SIGNAL(clicked()), SLOT(sl_complementLocation()));
-    connect(leGroupName, SIGNAL(textEdited(const QString &)), SIGNAL(si_groupNameEdited()));
-    connect(leGroupName, SIGNAL(textChanged(const QString &)), SIGNAL(si_groupNameEdited()));
-    connect(leAnnotationName, SIGNAL(textEdited(const QString &)), SIGNAL(si_annotationNameEdited()));
-    connect(leAnnotationName, SIGNAL(textChanged(const QString &)), SIGNAL(si_annotationNameEdited()));
+    connect(leGroupName, SIGNAL(textEdited(const QString&)), SIGNAL(si_groupNameEdited()));
+    connect(leGroupName, SIGNAL(textChanged(const QString&)), SIGNAL(si_groupNameEdited()));
+    connect(leAnnotationName, SIGNAL(textEdited(const QString&)), SIGNAL(si_annotationNameEdited()));
+    connect(leAnnotationName, SIGNAL(textChanged(const QString&)), SIGNAL(si_annotationNameEdited()));
     connect(chbUsePatternNames, SIGNAL(stateChanged(int)), SIGNAL(si_usePatternNamesStateChanged()));
 }
 
-}   // namespace U2
+}  // namespace U2
