@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -23,10 +23,8 @@
 
 namespace U2 {
 
-TophatSample::TophatSample(const QString &name, const QStringList &datasets)
-: name(name), datasets(datasets)
-{
-
+TophatSample::TophatSample(const QString& name, const QStringList& datasets)
+    : name(name), datasets(datasets) {
 }
 
-} // U2
+}  // namespace U2
