@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,9 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef GTTESTS_WORKFLOW_ESTIMATING_H_
-#define GTTESTS_WORKFLOW_ESTIMATING_H_
+#pragma once
 
-#include <U2Test/UGUITestBase.h>
+#include <harness/UGUITestBase.h>
 
 namespace U2 {
 
@@ -34,8 +33,6 @@ GUI_TEST_CLASS_DECLARATION(test_0001)
 GUI_TEST_CLASS_DECLARATION(test_0002)
 
 #undef GUI_TEST_SUITE
-}
+}  // namespace GUITest_common_scenarios_workflow_estimating
 
-} // namespace U2
-
-#endif // GTTESTS_WORKFLOW_ESTIMATING_H_
+}  // namespace U2
