@@ -1,7 +1,7 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
- * http://ugene.unipro.ru
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
+ * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,46 +20,52 @@
  */
 
 #include "ImportAnnotationsFromCSVDialog.h"
-#include "ImportAnnotationsFromCSVTask.h"
-#include "CSVColumnConfigurationDialog.h"
 
-#include <U2Core/L10n.h>
+#include <QFileInfo>
+#include <QMessageBox>
+
+#include <U2Core/Annotation.h>
+#include <U2Core/AppContext.h>
+#include <U2Core/BaseDocumentFormats.h>
+#include <U2Core/FileFilters.h>
 #include <U2Core/IOAdapter.h>
 #include <U2Core/IOAdapterUtils.h>
-#include <U2Core/AppContext.h>
+#include <U2Core/L10n.h>
+#include <U2Core/QObjectScopedPointer.h>
 #include <U2Core/Settings.h>
 #include <U2Core/TextUtils.h>
+#include <U2Core/U2SafePoints.h>
 
-#include <U2Core/AnnotationTableObject.h>
-
-#include <U2Gui/ScriptEditorDialog.h>
+#include <U2Gui/HelpButton.h>
 #include <U2Gui/LastUsedDirHelper.h>
-#include <U2Gui/DialogUtils.h>
-#include <U2Gui/SaveDocumentGroupController.h>
+#include <U2Gui/SaveDocumentController.h>
+#include <U2Gui/ScriptEditorDialog.h>
+#include <U2Gui/U2FileDialog.h>
 
-#include <QtCore/QFileInfo>
-#include <QtGui/QFileDialog>
-#include <QtGui/QMessageBox>
+#include "CSVColumnConfigurationDialog.h"
+#include "ImportAnnotationsFromCSVTask.h"
 
-#include <memory>
-
-//TODO: add complement token configuration
-//TODO: autodetect numeric columns, propose using them as start/end/length positions
-//TODO: option for negative len -> complement
+// TODO: add complement token configuration
+// TODO: autodetect numeric columns, propose using them as start/end/length positions
+// TODO: option for negative len -> complement
 
 namespace U2 {
 
 // TODO: unify with plugin settings
-#define SETTINGS_ROOT       QString("dna_export/import_annotations_from_csv/")
-#define A_NAME              QString("annotation_name")
-#define T_SEPARATOR         QString("token_separator")
-#define SKIP_LINES_COUNT    QString("skip_lines_count")
-#define SKIP_LINES_PREFIX   QString("skip_lines_prefix")
+#define SETTINGS_ROOT QString("dna_export/import_annotations_from_csv/")
+#define A_NAME QString("annotation_name")
+#define T_SEPARATOR QString("token_separator")
+#define SKIP_LINES_COUNT QString("skip_lines_count")
+#define SKIP_LINES_PREFIX QString("skip_lines_prefix")
 
-ImportAnnotationsFromCSVDialog::ImportAnnotationsFromCSVDialog(QWidget* w) 
-: QDialog (w)
-{
+ImportAnnotationsFromCSVDialog::ImportAnnotationsFromCSVDialog(QWidget* w)
+    : QDialog(w),
+      saveController(nullptr) {
     setupUi(this);
+    new HelpButton(this, buttonBox, "65929493");
+    buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Run"));
+    buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
+
     connect(readFileButton, SIGNAL(clicked()), SLOT(sl_readFileClicked()));
     connect(previewButton, SIGNAL(clicked()), SLOT(sl_previewClicked()));
     connect(guessButton, SIGNAL(clicked()), SLOT(sl_guessSeparatorClicked()));
@@ -70,28 +76,18 @@ ImportAnnotationsFromCSVDialog::ImportAnnotationsFromCSVDialog(QWidget* w)
     connect(previewTable->horizontalHeader(), SIGNAL(sectionClicked(int)), SLOT(sl_tableHeaderClicked(int)));
     connect(columnSeparatorRadioButton, SIGNAL(toggled(bool)), SLOT(sl_separatorRadioToggled(bool)));
     connect(scriptRadioButton, SIGNAL(toggled(bool)), SLOT(sl_scriptRadioToggled(bool)));
-    
-    SaveDocumentGroupControllerConfig conf;
-    conf.dfc.addFlagToSupport(DocumentFormatFlag_SupportWriting);
-    conf.dfc.supportedObjectTypes += GObjectTypes::ANNOTATION_TABLE;
-    conf.fileDialogButton = saveFileButton;
-    conf.fileNameEdit = saveFileName;
-    conf.saveTitle = tr("Save imported annotations to");
-    conf.parentWidget = this;
-    conf.formatCombo = saveFormatCombo;
 
-    saveGroupController = new SaveDocumentGroupController(conf, this);
-    
+    initSaveController();
+
     sl_separatorChanged(separatorEdit->text());
     sl_prefixToSkipChanged(prefixToSkipEdit->text());
 
-
-    //restore last settings
+    // restore last settings
     QString lastName = AppContext::getSettings()->getValue(SETTINGS_ROOT + A_NAME).toString();
     if (!lastName.isEmpty()) {
         defaultNameEdit->setText(lastName);
     }
-    
+
     QString separator = AppContext::getSettings()->getValue(SETTINGS_ROOT + T_SEPARATOR).toString();
     if (!separator.isEmpty()) {
         separatorEdit->setText(separator);
@@ -106,15 +102,16 @@ ImportAnnotationsFromCSVDialog::ImportAnnotationsFromCSVDialog(QWidget* w)
     }
 
     scriptHeader = tr("//The script parses input line\n // and returns an array of parsed elements as the result\nvar %1; //input line\nvar %2; //parsed line number")
-        .arg(ReadCSVAsAnnotationsTask::LINE_VAR).arg(ReadCSVAsAnnotationsTask::LINE_NUM_VAR);
-    
+                       .arg(ReadCSVAsAnnotationsTask::LINE_VAR)
+                       .arg(ReadCSVAsAnnotationsTask::LINE_NUM_VAR);
+
     columnSeparatorRadioButton->setChecked(true);
     sl_scriptRadioToggled(false);
 
     separatorEdit->setMaxLength(SEPARATOR_EDIT_MAX_LENGTH);
 
     // connect this slot after initial dialog model is set up
-    connect(removeQuotesCheck, SIGNAL(toggled(bool)),SLOT(sl_removeQuotesToggled(bool)));
+    connect(removeQuotesCheck, SIGNAL(toggled(bool)), SLOT(sl_removeQuotesToggled(bool)));
     connect(linesToSkipBox, SIGNAL(valueChanged(int)), SLOT(sl_linesToSkipChanged(int)));
 }
 
@@ -131,28 +128,39 @@ void ImportAnnotationsFromCSVDialog::accept() {
     if (outFile.isEmpty()) {
         return;
     }
-    
-    //check that position is OK
+
+    // check that position is OK
     int endPos = 0;
     int startPos = 0;
     int length = 0;
     int names = 0;
     foreach (const ColumnConfig& conf, columnsConfig) {
-        switch(conf.role) {
-            case ColumnRole_EndPos: endPos++; break;
-            case ColumnRole_StartPos: startPos++; break;
-            case ColumnRole_Length: length++; break;
-            case ColumnRole_Name: names++; break;
-            case ColumnRole_Ignore: break;
-            case ColumnRole_Qualifier: break;
+        switch (conf.role) {
+            case ColumnRole_EndPos:
+                endPos++;
+                break;
+            case ColumnRole_StartPos:
+                startPos++;
+                break;
+            case ColumnRole_Length:
+                length++;
+                break;
+            case ColumnRole_Name:
+                names++;
+                break;
+            case ColumnRole_Ignore:
+                break;
+            case ColumnRole_Qualifier:
+                break;
             default:;
         }
     }
-    if (endPos + startPos + length < 2  || endPos > 1 || startPos > 1 || length > 1) {
-        QMessageBox::critical(this, L10N::errorTitle(), tr("Invalid start position/end position/length configuration!"));
+    if (endPos + startPos + length < 2 || endPos > 1 || startPos > 1 || length > 1) {
+        QMessageBox::critical(this, L10N::errorTitle(), tr("Invalid [start position] or [end position] or [length] column assignment!\n\n"
+                                                           "Please assign a column role by clicking on a column header in 'Results preview'"));
         return;
     }
-    if (names > 1 ) {
+    if (names > 1) {
         QMessageBox::critical(this, L10N::errorTitle(), tr("Multiple columns are used as a name!"));
         return;
     }
@@ -162,7 +170,7 @@ void ImportAnnotationsFromCSVDialog::accept() {
         return;
     }
 
-    //store last settings
+    // store last settings
     AppContext::getSettings()->setValue(SETTINGS_ROOT + A_NAME, defaultNameEdit->text());
     AppContext::getSettings()->setValue(SETTINGS_ROOT + T_SEPARATOR, separatorEdit->text());
     AppContext::getSettings()->setValue(SETTINGS_ROOT + SKIP_LINES_COUNT, linesToSkipBox->value());
@@ -181,9 +189,9 @@ void ImportAnnotationsFromCSVDialog::toParsingConfig(CSVParsingConfig& config) c
 
     config.parsingScript.clear();
     config.splitToken.clear();
-    if( columnSeparatorRadioButton->isChecked() ) {
+    if (columnSeparatorRadioButton->isChecked()) {
         config.splitToken = separatorEdit->text();
-    } else if( scriptRadioButton->isChecked() ) {
+    } else if (scriptRadioButton->isChecked()) {
         config.parsingScript = parsingScript;
     } else {
         assert(false);
@@ -194,8 +202,8 @@ void ImportAnnotationsFromCSVDialog::toTaskConfig(ImportAnnotationsFromCSVTaskCo
     assert(result() == QDialog::Accepted);
     toParsingConfig(config.parsingOptions);
     config.csvFile = readFileName->text();
-    config.df = saveGroupController->getFormatToSave();
-    config.dstFile = saveGroupController->getSaveFileName();
+    config.formatId = saveController->getFormatIdToSave();
+    config.dstFile = saveController->getSaveFileName();
     config.addToProject = addToProjectCheck->isChecked();
 }
 
@@ -203,7 +211,7 @@ void ImportAnnotationsFromCSVDialog::toTaskConfig(ImportAnnotationsFromCSVTaskCo
 QString ImportAnnotationsFromCSVDialog::readFileHeader(const QString& fileName, bool silentFail) {
     IOAdapterId ioId = IOAdapterUtils::url2io(fileName);
     IOAdapterFactory* iof = AppContext::getIOAdapterRegistry()->getIOAdapterFactoryById(ioId);
-    std::auto_ptr<IOAdapter> io(iof->createIOAdapter());
+    QScopedPointer<IOAdapter> io(iof->createIOAdapter());
     bool ok = io->open(fileName, IOAdapterMode_Read);
     if (!ok) {
         if (!silentFail) {
@@ -222,7 +230,6 @@ QString ImportAnnotationsFromCSVDialog::readFileHeader(const QString& fileName,
             readFileName->setFocus();
         }
         return QString();
-
     }
     assert(bytesRead >= 0);
     previewBuff.resize(bytesRead);
@@ -237,6 +244,23 @@ void ImportAnnotationsFromCSVDialog::sl_linesToSkipChanged(int) {
     guessSeparator(true);
 }
 
+void ImportAnnotationsFromCSVDialog::initSaveController() {
+    SaveDocumentControllerConfig config;
+    config.fileDialogButton = saveFileButton;
+    config.fileNameEdit = saveFileName;
+    config.formatCombo = saveFormatCombo;
+    config.parentWidget = this;
+    config.saveTitle = tr("Save imported annotations to");
+    config.defaultFormatId = BaseDocumentFormats::PLAIN_GENBANK;
+
+    DocumentFormatConstraints formatConstraints;
+    formatConstraints.supportedObjectTypes << GObjectTypes::ANNOTATION_TABLE;
+    formatConstraints.addFlagToSupport(DocumentFormatFlag_SupportWriting);
+    formatConstraints.formatsToExclude << BaseDocumentFormats::VECTOR_NTI_SEQUENCE;
+
+    saveController = new SaveDocumentController(config, formatConstraints, this);
+}
+
 void ImportAnnotationsFromCSVDialog::sl_guessSeparatorClicked() {
     guessSeparator(false);
 }
@@ -245,21 +269,23 @@ void ImportAnnotationsFromCSVDialog::sl_scriptSeparatorClicked() {
     if (parsingScript.isEmpty()) {
         lastUsedSeparator = separatorEdit->text();
     }
-    ScriptEditorDialog d(this, scriptHeader);
+    QObjectScopedPointer<ScriptEditorDialog> d = new ScriptEditorDialog(this, scriptHeader);
     if (!parsingScript.isEmpty()) {
-        d.setScriptText(parsingScript);
-    } else { //set sample script
-        QString l1 = "var firstColumn = ["+ReadCSVAsAnnotationsTask::LINE_NUM_VAR+"];\n";
-        QString l2 = "var otherColumns = "+ReadCSVAsAnnotationsTask::LINE_VAR+".split(\" \");\n";
+        d->setScriptText(parsingScript);
+    } else {  // set sample script
+        QString l1 = "var firstColumn = [" + ReadCSVAsAnnotationsTask::LINE_NUM_VAR + "];\n";
+        QString l2 = "var otherColumns = " + ReadCSVAsAnnotationsTask::LINE_VAR + ".split(\" \");\n";
         QString l3 = "result =firstColumn.concat(otherColumns);";
-        d.setScriptText(l1 + l2 + l3);
+        d->setScriptText(l1 + l2 + l3);
     }
 
-    int rc = d.exec();
+    const int rc = d->exec();
+    CHECK(!d.isNull(), );
+
     if (rc != QDialog::Accepted) {
         return;
     }
-    parsingScript = d.getScriptText();
+    parsingScript = d->getScriptText();
     separatorEdit->setText(lastUsedSeparator);
 }
 
@@ -286,9 +312,9 @@ void ImportAnnotationsFromCSVDialog::guessSeparator(bool silent) {
 static QString toHex(const QString& text) {
     QString rawHex = text.toLocal8Bit().toHex();
     QString res;
-    for (int i=0; i<rawHex.size(); i+=2) {
+    for (int i = 0; i < rawHex.size(); i += 2) {
         QString hexPart = rawHex.mid(i, 2);
-        res += (res.length() > 0 ? " ": "") + hexPart;
+        res += (res.length() > 0 ? " " : "") + hexPart;
     }
     return res;
 }
@@ -298,7 +324,9 @@ void ImportAnnotationsFromCSVDialog::sl_separatorChanged(const QString& v) {
         separatorLabel->setText(tr("Column separator"));
     } else {
         separatorLabel->setText(tr("Column separator value: [%1], hex: [%2], length: %3")
-            .arg(v).arg(toHex(v)).arg(v.length()));
+                                    .arg(v)
+                                    .arg(toHex(v))
+                                    .arg(v.length()));
         if (v.trimmed().length() == 0) {
             separatorsModeCheck->setChecked(true);
         }
@@ -315,13 +343,13 @@ void ImportAnnotationsFromCSVDialog::sl_prefixToSkipChanged(const QString& v) {
 void ImportAnnotationsFromCSVDialog::sl_readFileClicked() {
     // show the dialog
     LastUsedDirHelper lod("CSV");
-    QString filter = DialogUtils::prepareFileFilter(tr("CSV Files"), QStringList() << "csv", true, QStringList());
-    lod.url = QFileDialog::getOpenFileName(this, tr("Select CSV file to read"), lod, filter);
+    QString filter = FileFilters::createFileFilter(tr("CSV Files"), {"csv"});
+    lod.url = U2FileDialog::getOpenFileName(this, tr("Select CSV file to read"), lod, filter);
     if (lod.url.isEmpty()) {
         return;
     }
     readFileName->setText(lod.url);
-    
+
     // guess separator & show preview
     guessSeparator(true);
 }
@@ -355,13 +383,13 @@ QString ImportAnnotationsFromCSVDialog::checkInputGroup(bool silent) {
 }
 
 bool ImportAnnotationsFromCSVDialog::checkSeparators(bool silent) {
-    if (columnSeparatorRadioButton->isChecked() && separatorEdit->text().isEmpty() ) {
+    if (columnSeparatorRadioButton->isChecked() && separatorEdit->text().isEmpty()) {
         if (!silent) {
             QMessageBox::critical(this, L10N::errorTitle(), tr("Separator value is not set"));
             separatorEdit->setFocus();
         }
         return false;
-    } else if( scriptRadioButton->isChecked() && parsingScript.isEmpty() ){
+    } else if (scriptRadioButton->isChecked() && parsingScript.isEmpty()) {
         if (!silent) {
             QMessageBox::critical(this, L10N::errorTitle(), tr("Script is empty"));
         }
@@ -371,17 +399,13 @@ bool ImportAnnotationsFromCSVDialog::checkSeparators(bool silent) {
 }
 
 QString ImportAnnotationsFromCSVDialog::checkOutputGroup() {
-    QString outFile = saveGroupController->getSaveFileName();
+    QString outFile = saveController->getSaveFileName();
     if (outFile.isEmpty()) {
         QMessageBox::critical(this, L10N::errorTitle(), tr("Output file name is not set!"));
         saveFileName->setFocus();
         return QString();
     }
-    if (saveGroupController->getFormatToSave() == NULL) {
-        QMessageBox::critical(this, L10N::errorTitle(), tr("Output file format is not set!"));
-        saveFormatCombo->setFocus();
-        return QString();
-    }
+
     return outFile;
 }
 
@@ -398,7 +422,7 @@ void ImportAnnotationsFromCSVDialog::preview(bool silent) {
 
     previewTable->clear();
     rawPreview->clear();
-    
+
     rawPreview->setPlainText(text);
 
     if (!checkSeparators(true)) {
@@ -409,7 +433,6 @@ void ImportAnnotationsFromCSVDialog::preview(bool silent) {
     if (parseOptions.splitToken.isEmpty() && parseOptions.parsingScript.isEmpty()) {
         return;
     }
-    
 
     int columnCount = 0;
     TaskStateInfo ti;
@@ -420,18 +443,18 @@ void ImportAnnotationsFromCSVDialog::preview(bool silent) {
     }
     prepareColumnsConfig(columnCount);
     columnCount = qMax(columnCount, columnsConfig.size());
-    
+
     previewTable->setRowCount(lines.size());
     previewTable->setColumnCount(columnCount);
-    
+
     for (int column = 0; column < columnCount; column++) {
         QTableWidgetItem* headerItem = createHeaderItem(column);
         previewTable->setHorizontalHeaderItem(column, headerItem);
     }
     for (int row = 0; row < lines.size(); row++) {
         const QStringList& rowData = lines.at(row);
-        for (int column = 0; column < rowData.size(); column ++) {
-            QString token = rowData.at(column);
+        for (int column = 0; column < rowData.size(); column++) {
+            const QString& token = rowData.at(column);
             QTableWidgetItem* item = new QTableWidgetItem(token);
             item->setFlags(Qt::ItemIsEnabled);
             previewTable->setItem(row, column, item);
@@ -453,7 +476,7 @@ void ImportAnnotationsFromCSVDialog::prepareColumnsConfig(int numColumns) {
 }
 
 QTableWidgetItem* ImportAnnotationsFromCSVDialog::createHeaderItem(int column) const {
-    assert(column >=0 && column < columnsConfig.size());
+    assert(column >= 0 && column < columnsConfig.size());
     QString text = getHeaderItemText(column);
     return new QTableWidgetItem(text);
 }
@@ -469,7 +492,7 @@ QString ImportAnnotationsFromCSVDialog::getHeaderItemText(int column) const {
             text = tr("[name]");
             break;
         case ColumnRole_StartPos:
-            if (config.startPositionOffset!=0) {
+            if (config.startPositionOffset != 0) {
                 text = tr("[start position with offset %1]").arg(config.startPositionOffset);
             } else {
                 text = tr("[start position]");
@@ -517,7 +540,7 @@ void ImportAnnotationsFromCSVDialog::sl_separatorRadioToggled(bool checked) {
 
 void ImportAnnotationsFromCSVDialog::sl_scriptRadioToggled(bool checked) {
     scriptButton->setEnabled(checked);
-    if(checked && parsingScript.isEmpty()) {
+    if (checked && parsingScript.isEmpty()) {
         sl_scriptSeparatorClicked();
     }
 }
@@ -526,11 +549,13 @@ void ImportAnnotationsFromCSVDialog::configureColumn(int column) {
     assert(column >= 0 && column < columnsConfig.size());
 
     const ColumnConfig& config = columnsConfig.at(column);
-    CSVColumnConfigurationDialog d(this, config);
-    int rc = d.exec(); // TODO: set dialog position close to the header item
+    QObjectScopedPointer<CSVColumnConfigurationDialog> d = new CSVColumnConfigurationDialog(this, config);
+    int rc = d->exec();  // TODO: set dialog position close to the header item
+    CHECK(!d.isNull(), );
     if (rc == QDialog::Accepted) {
-        columnsConfig[column] = d.config;
+        columnsConfig[column] = d->config;
     }
     previewTable->horizontalHeaderItem(column)->setText(getHeaderItemText(column));
 }
-} //namespace
+
+}  // namespace U2
