@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,16 +19,15 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_GRAPHPACK_ENTROPY_H_
-#define _U2_GRAPHPACK_ENTROPY_H_
+#pragma once
 
-#include "DNAGraphPackPlugin.h"
+#include <QAction>
+#include <QBitArray>
+#include <QList>
 
 #include <U2View/GSequenceGraphView.h>
 
-#include <QAction>
-#include <QList>
-#include <QBitArray>
+#include "DNAGraphPackPlugin.h"
 
 namespace U2 {
 
@@ -38,14 +37,13 @@ class EntropyGraphFactory : public GSequenceGraphFactory {
     Q_OBJECT
 public:
     EntropyGraphFactory(QObject* p);
-    QList<QSharedPointer<GSequenceGraphData> > createGraphs(GSequenceGraphView* v);
+    QList<QSharedPointer<GSequenceGraphData>> createGraphs(GSequenceGraphView* v);
     bool isEnabled(const U2SequenceObject* o) const;
 };
 
 class EntropyGraphAlgorithm : public GSequenceGraphAlgorithm {
 public:
-    void calculate(QVector<float>& res, U2SequenceObject* o, const U2Region& r, const GSequenceGraphWindowData* d, U2OpStatus &os);
+    void calculate(QVector<float>& result, U2SequenceObject* sequenceObject, qint64 window, qint64 step, U2OpStatus& os) override;
 };
 
-} // namespace
-#endif
+}  // namespace U2
