@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,30 +19,26 @@
  * MA 02110-1301, USA.
  */
 
+#include "MAFFTSupportRunDialog.h"
+
 #include <QMessageBox>
-#include <QPushButton>
-#include <QToolButton>
 
 #include <U2Core/DocumentUtils.h>
-#include <U2Core/GUrlUtils.h>
+#include <U2Core/FileFilters.h>
 
-#include <U2Gui/DialogUtils.h>
 #include <U2Gui/HelpButton.h>
 #include <U2Gui/LastUsedDirHelper.h>
 #include <U2Gui/SaveDocumentController.h>
 #include <U2Gui/U2FileDialog.h>
 
-#include "MAFFTSupportRunDialog.h"
-
 namespace U2 {
 
 ////////////////////////////////////////
-//MAFFTSupportRunDialog
-MAFFTSupportRunDialog::MAFFTSupportRunDialog(MAFFTSupportTaskSettings& _settings, QWidget* _parent) :
-    QDialog(_parent), settings(_settings)
-{
+// MAFFTSupportRunDialog
+MAFFTSupportRunDialog::MAFFTSupportRunDialog(MAFFTSupportTaskSettings& _settings, QWidget* _parent)
+    : QDialog(_parent), settings(_settings) {
     setupUi(this);
-    new HelpButton(this, buttonBox, "18223230");
+    new HelpButton(this, buttonBox, "65930844");
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Align"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
 
@@ -50,28 +46,27 @@ MAFFTSupportRunDialog::MAFFTSupportRunDialog(MAFFTSupportTaskSettings& _settings
     this->adjustSize();
 }
 
-void MAFFTSupportRunDialog::accept(){
-    if(gapOpenCheckBox->isChecked()) {
+void MAFFTSupportRunDialog::accept() {
+    if (gapOpenCheckBox->isChecked()) {
         settings.gapOpenPenalty = gapOpenSpinBox->value();
     }
-    if(gapExtCheckBox->isChecked()) {
+    if (gapExtCheckBox->isChecked()) {
         settings.gapExtenstionPenalty = gapExtSpinBox->value();
     }
-    if(maxNumberIterRefinementCheckBox->isChecked()){
+    if (maxNumberIterRefinementCheckBox->isChecked()) {
         settings.maxNumberIterRefinement = maxNumberIterRefinementSpinBox->value();
     }
     QDialog::accept();
 }
 
 ////////////////////////////////////////
-//MAFFTWithExtFileSpecifySupportRunDialog
-MAFFTWithExtFileSpecifySupportRunDialog::MAFFTWithExtFileSpecifySupportRunDialog(MAFFTSupportTaskSettings& _settings, QWidget* _parent) :
-    QDialog(_parent),
-    settings(_settings),
-    saveController(NULL)
-{
+// MAFFTWithExtFileSpecifySupportRunDialog
+MAFFTWithExtFileSpecifySupportRunDialog::MAFFTWithExtFileSpecifySupportRunDialog(MAFFTSupportTaskSettings& _settings, QWidget* _parent)
+    : QDialog(_parent),
+      settings(_settings),
+      saveController(nullptr) {
     setupUi(this);
-    new HelpButton(this, buttonBox, "18223230");
+    new HelpButton(this, buttonBox, "65930844");
 
     buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Align"));
     buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
@@ -83,8 +78,7 @@ MAFFTWithExtFileSpecifySupportRunDialog::MAFFTWithExtFileSpecifySupportRunDialog
 
 void MAFFTWithExtFileSpecifySupportRunDialog::sl_inputPathButtonClicked() {
     LastUsedDirHelper lod;
-    lod.url = U2FileDialog::getOpenFileName(this, tr("Open an alignment file"), lod.dir,
-        DialogUtils::prepareDocumentsFileFilterByObjType(GObjectTypes::MULTIPLE_ALIGNMENT, true));
+    lod.url = U2FileDialog::getOpenFileName(this, tr("Open an alignment file"), lod.dir, FileFilters::createFileFilterByObjectTypes({GObjectTypes::MULTIPLE_SEQUENCE_ALIGNMENT}));
     if (lod.url.isEmpty()) {
         return;
     }
@@ -105,28 +99,25 @@ void MAFFTWithExtFileSpecifySupportRunDialog::initSaveController() {
     saveController = new SaveDocumentController(config, formats, this);
 }
 
-void MAFFTWithExtFileSpecifySupportRunDialog::accept(){
-    if(gapOpenCheckBox->isChecked()) {
+void MAFFTWithExtFileSpecifySupportRunDialog::accept() {
+    if (gapOpenCheckBox->isChecked()) {
         settings.gapOpenPenalty = gapOpenSpinBox->value();
     }
-    if(gapExtCheckBox->isChecked()) {
+    if (gapExtCheckBox->isChecked()) {
         settings.gapExtenstionPenalty = gapExtSpinBox->value();
     }
-    if(maxNumberIterRefinementCheckBox->isChecked()){
+    if (maxNumberIterRefinementCheckBox->isChecked()) {
         settings.maxNumberIterRefinement = maxNumberIterRefinementSpinBox->value();
     }
-    if(inputFileLineEdit->text().isEmpty()){
-        QMessageBox::information(this, tr("Kalign with Align"),
-                                 tr("Input file is not set!") );
-    }else if(saveController->getSaveFileName().isEmpty()){
-        QMessageBox::information(this, tr("Kalign with Align"),
-                                 tr("Output file is not set!") );
-    }
-    else{
+    if (inputFileLineEdit->text().isEmpty()) {
+        QMessageBox::information(this, tr("Align with MAFFT"), tr("Input file is not set!"));
+    } else if (saveController->getSaveFileName().isEmpty()) {
+        QMessageBox::information(this, tr("Align with MAFFT"), tr("Output file is not set!"));
+    } else {
         settings.outputFilePath = saveController->getSaveFileName();
         settings.inputFilePath = inputFileLineEdit->text();
         QDialog::accept();
     }
 }
 
-}//namespace
+}  // namespace U2
