@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_SPADES_SUPPORT_H_
-#define _U2_SPADES_SUPPORT_H_
+#pragma once
 
 #include "U2Core/ExternalToolRegistry.h"
 
@@ -28,13 +27,16 @@ namespace U2 {
 
 class SpadesSupport : public ExternalTool {
     Q_OBJECT
+
 public:
-    SpadesSupport(const QString& id, const QString &name, const QString &path = "");
+    /** Registers SPAdes tool in UGENE. */
+    static void checkIn();
 
     static const QString ET_SPADES;
     static const QString ET_SPADES_ID;
+
+private:
+    SpadesSupport();
 };
 
-} // namespace U2
-
-#endif // _U2_SPADES_SUPPORT_H_
+}  // namespace U2
