@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -20,28 +20,27 @@
  */
 
 #include "PerfMonitorPlugin.h"
-#include "PerfMonitorView.h"
+
+#include <QMenu>
 
 #include <U2Core/AppContext.h>
+
 #include <U2Gui/MainWindow.h>
 
-#if (QT_VERSION < 0x050000) //Qt 5
-#include <QtGui/QMenu>
-#else
-#include <QtWidgets/QMenu>
-#endif
+#include "PerfMonitorView.h"
 
 namespace U2 {
 
-extern "C" Q_DECL_EXPORT Plugin * U2_PLUGIN_INIT_FUNC() {
+extern "C" Q_DECL_EXPORT Plugin* U2_PLUGIN_INIT_FUNC() {
     if (AppContext::getMainWindow()) {
-        PerfMonitorPlugin * plug = new PerfMonitorPlugin();
+        PerfMonitorPlugin* plug = new PerfMonitorPlugin();
         return plug;
     }
-    return NULL;
+    return nullptr;
 }
 
-PerfMonitorPlugin::PerfMonitorPlugin() : Plugin( tr("Performance Monitor"), tr("Shows performance counters") ) {
+PerfMonitorPlugin::PerfMonitorPlugin()
+    : Plugin(tr("Performance Monitor"), tr("Shows performance counters")) {
     windowId = 0;
     openWindowAction = new QAction(tr("Show counters"), this);
     openWindowAction->setObjectName("Show counters");
@@ -55,14 +54,13 @@ PerfMonitorPlugin::PerfMonitorPlugin() : Plugin( tr("Performance Monitor"), tr("
 void PerfMonitorPlugin::sl_openWindow() {
     MWMDIManager* mdi = AppContext::getMainWindow()->getMDIManager();
     MWMDIWindow* mdiWindow = mdi->getWindowById(windowId);
-    if (mdiWindow==NULL) {
+    if (mdiWindow == nullptr) {
         mdiWindow = new PerfMonitorView();
         mdiWindow->setWindowIcon(QIcon(":perf_monitor/images/mon.png"));
         windowId = mdiWindow->getId();
         mdi->addMDIWindow(mdiWindow);
     }
     mdi->activateWindow(mdiWindow);
-
 }
 
-} //namespace
+}  // namespace U2
