@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _U2_QUERY_PALETTE_H_
-#define _U2_QUERY_PALETTE_H_
+#pragma once
 
 #include <QAction>
 #include <QTreeWidget>
@@ -40,35 +39,36 @@ class QueryPalette : public QTreeWidget {
     Q_OBJECT
 public:
     static const QString MIME_TYPE;
-    QueryPalette(QWidget* parent=NULL);
+    QueryPalette(QWidget* parent = nullptr);
 
     QVariant saveState() const;
     void restoreState(const QVariant&);
     void resetSelection();
 signals:
     void processSelected(QDActorPrototype*);
+
 protected:
-    void mousePressEvent(QMouseEvent *event);
-    void mouseMoveEvent(QMouseEvent *event);
-    void leaveEvent(QEvent *);
+    void mousePressEvent(QMouseEvent* event);
+    void mouseMoveEvent(QMouseEvent* event);
+    void leaveEvent(QEvent*);
 private slots:
-    void sl_selectProcess(bool checked=false);
+    void sl_selectProcess(bool checked = false);
+
 private:
     void setContent();
     QAction* createItemAction(QDActorPrototype* item);
     QAction* createItemAction(const QString& constraintId);
+
 private:
     QTreeWidgetItem* overItem;
     QAction* currentAction;
-    QPoint  dragStartPosition;
+    QPoint dragStartPosition;
     //  < category id, item ids > ids r used as display names
-    QMap< QString, QList<QString> > categoryMap;
+    QMap<QString, QList<QString>> categoryMap;
     QMap<QAction*, QTreeWidgetItem*> actionMap;
     friend class PaletteDelegate;
 };
 
-}//namespace
+}  // namespace U2
 
-Q_DECLARE_METATYPE(QAction *)
-
-#endif
+Q_DECLARE_METATYPE(QAction*)
