@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2018 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _DB_REQUEST_FACTORY_
-#define _DB_REQUEST_FACTORY_
+#pragma once
 
 #include <U2Core/DataBaseRegistry.h>
 
@@ -28,11 +27,10 @@
 
 namespace U2 {
 
-class BLASTFactory: public DataBaseFactory {
-    HttpRequest* getRequest(Task *t) {return new HttpRequestBLAST(t);}
+class BLASTFactory : public DataBaseFactory {
+    HttpRequest* getRequest(Task* t) {
+        return new HttpRequestBLAST(t);
+    }
 };
 
-}
-
-
-#endif
+}  // namespace U2
