@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,6 +19,8 @@
  * MA 02110-1301, USA.
  */
 
+#include "CfgExternalToolModel.h"
+
 #include <U2Core/AppContext.h>
 #include <U2Core/BaseDocumentFormats.h>
 #include <U2Core/DocumentModel.h>
@@ -29,7 +31,6 @@
 #include <U2Lang/WorkflowEnv.h>
 #include <U2Lang/WorkflowUtils.h>
 
-#include "CfgExternalToolModel.h"
 #include "../WorkflowEditorDelegates.h"
 
 namespace U2 {
@@ -38,7 +39,7 @@ namespace U2 {
 /// CfgExternalToolModel
 //////////////////////////////////////////////////////////////////////////
 
-CfgExternalToolItem::CfgExternalToolItem()  {
+CfgExternalToolItem::CfgExternalToolItem() {
     dfr = AppContext::getDocumentFormatRegistry();
     dtr = Workflow::WorkflowEnv::getDataTypeRegistry();
 
@@ -57,7 +58,7 @@ CfgExternalToolItem::~CfgExternalToolItem() {
     delete delegateForFormats;
 }
 
-const QString &CfgExternalToolItem::getDataType() const {
+const QString& CfgExternalToolItem::getDataType() const {
     return itemData.type;
 }
 
@@ -65,35 +66,35 @@ void CfgExternalToolItem::setDataType(const QString& id) {
     itemData.type = id;
 }
 
-const QString &CfgExternalToolItem::getId() const {
+const QString& CfgExternalToolItem::getId() const {
     return itemData.attributeId;
 }
 
-void CfgExternalToolItem::setId(const QString &_id) {
+void CfgExternalToolItem::setId(const QString& _id) {
     itemData.attributeId = _id;
 }
 
-const QString &CfgExternalToolItem::getName() const {
+const QString& CfgExternalToolItem::getName() const {
     return itemData.attrName;
 }
 
-void CfgExternalToolItem::setName(const QString &_name) {
+void CfgExternalToolItem::setName(const QString& _name) {
     itemData.attrName = _name;
 }
 
-const QString &CfgExternalToolItem::getFormat() const {
+const QString& CfgExternalToolItem::getFormat() const {
     return itemData.format;
 }
 
-void CfgExternalToolItem::setFormat(const QString & f) {
+void CfgExternalToolItem::setFormat(const QString& f) {
     itemData.format = f;
 }
 
-const QString &CfgExternalToolItem::getDescription() const {
+const QString& CfgExternalToolItem::getDescription() const {
     return itemData.description;
 }
 
-void CfgExternalToolItem::setDescription(const QString & _descr) {
+void CfgExternalToolItem::setDescription(const QString& _descr) {
     itemData.description = _descr;
 }
 
@@ -101,26 +102,25 @@ void CfgExternalToolItem::setDescription(const QString & _descr) {
 /// CfgExternalToolModel
 //////////////////////////////////////////////////////////////////////////
 
-CfgExternalToolModel::CfgExternalToolModel(CfgExternalToolModel::ModelType _modelType, QObject *_obj)
+CfgExternalToolModel::CfgExternalToolModel(CfgExternalToolModel::ModelType _modelType, QObject* _obj)
     : QAbstractTableModel(_obj),
-      isInput(Input == _modelType)
-{
+      isInput(Input == _modelType) {
     init();
 }
 
-int CfgExternalToolModel::rowCount(const QModelIndex & /*index*/) const{
+int CfgExternalToolModel::rowCount(const QModelIndex& /*index*/) const {
     return items.size();
 }
 
-int CfgExternalToolModel::columnCount(const QModelIndex & /*index*/) const {
+int CfgExternalToolModel::columnCount(const QModelIndex& /*index*/) const {
     return COLUMNS_COUNT;
 }
 
-Qt::ItemFlags CfgExternalToolModel::flags(const QModelIndex & /*index*/) const{
+Qt::ItemFlags CfgExternalToolModel::flags(const QModelIndex& /*index*/) const {
     return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
 
-CfgExternalToolItem* CfgExternalToolModel::getItem(const QModelIndex &index) const {
+CfgExternalToolItem* CfgExternalToolModel::getItem(const QModelIndex& index) const {
     return items.at(index.row());
 }
 
@@ -128,67 +128,67 @@ QList<CfgExternalToolItem*> CfgExternalToolModel::getItems() const {
     return items;
 }
 
-QVariant CfgExternalToolModel::data(const QModelIndex &index, int role) const {
-    CfgExternalToolItem *item = getItem(index);
+QVariant CfgExternalToolModel::data(const QModelIndex& index, int role) const {
+    CfgExternalToolItem* item = getItem(index);
     int col = index.column();
 
     switch (role) {
-    case Qt::DisplayRole: // fallthrough
-    case Qt::ToolTipRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return item->getName();
-        case COLUMN_ID:
-            return item->getId();
-        case COLUMN_DATA_TYPE:
-            return item->delegateForTypes->getDisplayValue(item->getDataType());
-        case COLUMN_FORMAT:
-            return item->delegateForFormats->getDisplayValue(item->getFormat());
-        case COLUMN_DESCRIPTION:
-            return item->getDescription();
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
-        }
-    case DelegateRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForNames);
-        case COLUMN_ID:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForIds);
-        case COLUMN_DATA_TYPE:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForTypes);
-        case COLUMN_FORMAT:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForFormats);
+        case Qt::DisplayRole:  // fallthrough
+        case Qt::ToolTipRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return item->getName();
+                case COLUMN_ID:
+                    return item->getId();
+                case COLUMN_DATA_TYPE:
+                    return item->delegateForTypes->getDisplayValue(item->getDataType());
+                case COLUMN_FORMAT:
+                    return item->delegateForFormats->getDisplayValue(item->getFormat());
+                case COLUMN_DESCRIPTION:
+                    return item->getDescription();
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
+                    return QVariant();
+            }
+        case DelegateRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForNames);
+                case COLUMN_ID:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForIds);
+                case COLUMN_DATA_TYPE:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForTypes);
+                case COLUMN_FORMAT:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForFormats);
+                default:
+                    return QVariant();
+            }
+        case Qt::EditRole:  // fallthrough
+        case ConfigurationEditor::ItemValueRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return item->getName();
+                case COLUMN_ID:
+                    return item->getId();
+                case COLUMN_DATA_TYPE:
+                    return item->getDataType();
+                case COLUMN_FORMAT:
+                    return item->getFormat();
+                case COLUMN_DESCRIPTION:
+                    return item->getDescription();
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
+                    return QVariant();
+            }
         default:
             return QVariant();
-        }
-    case Qt::EditRole: // fallthrough
-    case ConfigurationEditor::ItemValueRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return item->getName();
-        case COLUMN_ID:
-            return item->getId();
-        case COLUMN_DATA_TYPE:
-            return item->getDataType();
-        case COLUMN_FORMAT:
-            return item->getFormat();
-        case COLUMN_DESCRIPTION:
-            return item->getDescription();
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
-        }
-    default:
-        return QVariant();
     }
 }
 
-void CfgExternalToolModel::createFormatDelegate(const QString &newType, CfgExternalToolItem *item) {
-    PropertyDelegate *delegate;
+void CfgExternalToolModel::createFormatDelegate(const QString& newType, CfgExternalToolItem* item) {
+    PropertyDelegate* delegate;
     QString format;
     if (newType == BaseTypes::DNA_SEQUENCE_TYPE()->getId()) {
         delegate = new ComboBoxDelegate(seqFormatsW);
@@ -199,7 +199,7 @@ void CfgExternalToolModel::createFormatDelegate(const QString &newType, CfgExter
     } else if (newType == BaseTypes::ANNOTATION_TABLE_TYPE()->getId()) {
         delegate = new ComboBoxDelegate(annFormatsW);
         format = annFormatsW.values().first().toString();
-    } else if (newType == SEQ_WITH_ANNS){
+    } else if (newType == SEQ_WITH_ANNS) {
         delegate = new ComboBoxDelegate(annSeqFormatsW);
         format = annSeqFormatsW.values().first().toString();
     } else if (newType == BaseTypes::STRING_TYPE()->getId()) {
@@ -212,56 +212,55 @@ void CfgExternalToolModel::createFormatDelegate(const QString &newType, CfgExter
     item->delegateForFormats = delegate;
 }
 
-bool CfgExternalToolModel::setData(const QModelIndex &index, const QVariant &value, int role) {
+bool CfgExternalToolModel::setData(const QModelIndex& index, const QVariant& value, int role) {
     int col = index.column();
-    CfgExternalToolItem * item = getItem(index);
+    CfgExternalToolItem* item = getItem(index);
     switch (role) {
-    case Qt::EditRole: // fall through
-    case ConfigurationEditor::ItemValueRole:
-        switch (col) {
-        case COLUMN_NAME:
-            if (item->getName() != value.toString()) {
-                const QString oldGeneratedId = WorkflowUtils::generateIdFromName(item->getName());
-                const bool wasIdEditedByUser = (oldGeneratedId != item->getId());
-                item->setName(value.toString());
-                if (!wasIdEditedByUser) {
-                    item->setId(WorkflowUtils::generateIdFromName(item->getName()));
+        case Qt::EditRole:  // fall through
+        case ConfigurationEditor::ItemValueRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    if (item->getName() != value.toString()) {
+                        const QString oldGeneratedId = WorkflowUtils::generateIdFromName(item->getName());
+                        const bool wasIdEditedByUser = (oldGeneratedId != item->getId());
+                        item->setName(value.toString());
+                        if (!wasIdEditedByUser) {
+                            item->setId(WorkflowUtils::generateIdFromName(item->getName()));
+                        }
+                    }
+                    break;
+                case COLUMN_ID:
+                    if (item->getId() != value.toString()) {
+                        item->setId(value.toString());
+                    }
+                    break;
+                case COLUMN_DATA_TYPE: {
+                    QString newType = value.toString();
+                    if (item->getDataType() != newType) {
+                        if (!newType.isEmpty()) {
+                            item->setDataType(newType);
+                            createFormatDelegate(newType, item);
+                        }
+                    }
+                    break;
                 }
+                case COLUMN_FORMAT:
+                    if (item->getFormat() != value.toString() && !value.toString().isEmpty()) {
+                        item->setFormat(value.toString());
+                    }
+                    break;
+                case COLUMN_DESCRIPTION:
+                    if (item->getDescription() != value.toString()) {
+                        item->setDescription(value.toString());
+                    }
+                    break;
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
             }
-        break;
-        case COLUMN_ID:
-            if (item->getId() != value.toString()) {
-                item->setId(value.toString());
-            }
+            emit dataChanged(index, index);
             break;
-        case COLUMN_DATA_TYPE: {
-            QString newType = value.toString();
-            if (item->getDataType() != newType) {
-                if (!newType.isEmpty()) {
-                    item->setDataType(newType);
-                    createFormatDelegate(newType, item);
-                }
-            }
-            break;
-        }
-        case COLUMN_FORMAT:
-            if (item->getFormat() != value.toString() && !value.toString().isEmpty())  {
-                item->setFormat(value.toString());
-            }
-            break;
-        case COLUMN_DESCRIPTION:
-            if (item->getDescription() != value.toString()) {
-                item->setDescription(value.toString());
-            }
-            break;
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-        }
-        emit dataChanged(index, index);
-        break;
-    default:
-        ; // do nothing
+        default:;  // do nothing
     }
     return true;
 }
@@ -269,32 +268,32 @@ bool CfgExternalToolModel::setData(const QModelIndex &index, const QVariant &val
 QVariant CfgExternalToolModel::headerData(int section, Qt::Orientation orientation, int role) const {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-        case COLUMN_NAME:
-            return tr("Display name");
-        case COLUMN_ID:
-            return tr("Argument name");
-        case COLUMN_DATA_TYPE:
-            return tr("Type");
-        case COLUMN_FORMAT:
-            if (isInput) {
-                return tr("Argument value");
-            } else {
-                return tr("Argument value");
-            }
-        case COLUMN_DESCRIPTION:
-            return tr("Description");
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
+            case COLUMN_NAME:
+                return tr("Display name");
+            case COLUMN_ID:
+                return tr("Argument name");
+            case COLUMN_DATA_TYPE:
+                return tr("Type");
+            case COLUMN_FORMAT:
+                if (isInput) {
+                    return tr("Argument value");
+                } else {
+                    return tr("Argument value");
+                }
+            case COLUMN_DESCRIPTION:
+                return tr("Description");
+            default:
+                // do nothing, inaccessible code
+                Q_ASSERT(false);
+                return QVariant();
         }
     }
     return QVariant();
 }
 
-bool CfgExternalToolModel::insertRows(int /*row*/, int /*count*/, const QModelIndex &parent) {
+bool CfgExternalToolModel::insertRows(int /*row*/, int /*count*/, const QModelIndex& parent) {
     beginInsertRows(parent, items.size(), items.size());
-    CfgExternalToolItem *newItem = new CfgExternalToolItem();
+    CfgExternalToolItem* newItem = new CfgExternalToolItem();
     newItem->delegateForNames = new LineEditWithValidatorDelegate(WorkflowEntityValidator::ACCEPTABLE_NAME);
     newItem->delegateForIds = new LineEditWithValidatorDelegate(WorkflowEntityValidator::ACCEPTABLE_ID);
     newItem->delegateForTypes = new ComboBoxDelegate(types);
@@ -304,7 +303,7 @@ bool CfgExternalToolModel::insertRows(int /*row*/, int /*count*/, const QModelIn
     return true;
 }
 
-bool CfgExternalToolModel::removeRows(int row, int count, const QModelIndex &parent) {
+bool CfgExternalToolModel::removeRows(int row, int count, const QModelIndex& parent) {
     CHECK(0 <= row && row < items.size(), false);
     CHECK(0 <= row + count - 1 && row + count - 1 < items.size(), false);
     CHECK(0 < count, false);
@@ -357,7 +356,7 @@ void CfgExternalToolModel::initFormats() {
     annSeqRead.supportedObjectTypes += GObjectTypes::SEQUENCE;
 
     QString argumentValue(tr("URL to %1 file with data"));
-    foreach(const DocumentFormatId& id, ids) {
+    foreach (const DocumentFormatId& id, ids) {
         DocumentFormat* df = AppContext::getDocumentFormatRegistry()->getFormatById(id);
 
         QString formatNameKey = argumentValue.arg(df->getFormatName());
@@ -395,7 +394,7 @@ void CfgExternalToolModel::initFormats() {
         }
     }
 
-    DocumentFormat *df = AppContext::getDocumentFormatRegistry()->getFormatById(BaseDocumentFormats::PLAIN_TEXT);
+    DocumentFormat* df = AppContext::getDocumentFormatRegistry()->getFormatById(BaseDocumentFormats::PLAIN_TEXT);
     if (isInput) {
         textFormat[tr("String data value")] = DataConfig::STRING_VALUE;
     } else {
@@ -427,9 +426,7 @@ void CfgExternalToolModel::initTypes() {
 AttributeItem::AttributeItem()
     : delegateForNames(nullptr),
       delegateForIds(nullptr),
-      delegateForDefaultValues(nullptr)
-{
-
+      delegateForDefaultValues(nullptr) {
 }
 
 AttributeItem::~AttributeItem() {
@@ -438,15 +435,15 @@ AttributeItem::~AttributeItem() {
     delete delegateForDefaultValues;
 }
 
-const QString &AttributeItem::getId() const {
+const QString& AttributeItem::getId() const {
     return id;
 }
 
-void AttributeItem::setId(const QString &_id) {
+void AttributeItem::setId(const QString& _id) {
     id = _id;
 }
 
-const QString &AttributeItem::getName() const {
+const QString& AttributeItem::getName() const {
     return name;
 }
 
@@ -454,27 +451,27 @@ void AttributeItem::setName(const QString& _name) {
     name = _name;
 }
 
-const QString &AttributeItem::getDataType() const {
+const QString& AttributeItem::getDataType() const {
     return type;
 }
 
-void AttributeItem::setDataType(const QString &_type) {
+void AttributeItem::setDataType(const QString& _type) {
     type = _type;
 }
 
-const QVariant&AttributeItem::getDefaultValue() const {
+const QVariant& AttributeItem::getDefaultValue() const {
     return defaultValue;
 }
 
-void AttributeItem::setDefaultValue(const QVariant&_defaultValue) {
+void AttributeItem::setDefaultValue(const QVariant& _defaultValue) {
     defaultValue = _defaultValue;
 }
 
-const QString &AttributeItem::getDescription() const {
+const QString& AttributeItem::getDescription() const {
     return description;
 }
 
-void AttributeItem::setDescription(const QString &_description) {
+void AttributeItem::setDescription(const QString& _description) {
     description = _description;
 }
 
@@ -482,10 +479,9 @@ void AttributeItem::setDescription(const QString &_description) {
 /// CfgExternalToolModelAttributes
 //////////////////////////////////////////////////////////////////////////
 
-CfgExternalToolModelAttributes::CfgExternalToolModelAttributes(SchemaConfig* _schemaConfig, QObject *_parent)
+CfgExternalToolModelAttributes::CfgExternalToolModelAttributes(SchemaConfig* _schemaConfig, QObject* _parent)
     : QAbstractTableModel(_parent),
-    schemaConfig(_schemaConfig)
-{
+      schemaConfig(_schemaConfig) {
     types.append(QPair<QString, QVariant>(tr("Boolean"), AttributeConfig::BOOLEAN_TYPE));
     types.append(QPair<QString, QVariant>(tr("Integer"), AttributeConfig::INTEGER_TYPE));
     types.append(QPair<QString, QVariant>(tr("Double"), AttributeConfig::DOUBLE_TYPE));
@@ -498,7 +494,7 @@ CfgExternalToolModelAttributes::CfgExternalToolModelAttributes(SchemaConfig* _sc
 }
 
 CfgExternalToolModelAttributes::~CfgExternalToolModelAttributes() {
-    foreach(AttributeItem* item, items) {
+    foreach (AttributeItem* item, items) {
         delete item;
     }
 }
@@ -543,19 +539,19 @@ void CfgExternalToolModelAttributes::changeDefaultValueDelegate(const QString& n
     item->delegateForDefaultValues = propDelegate;
 }
 
-int CfgExternalToolModelAttributes::rowCount(const QModelIndex & /*index*/) const{
+int CfgExternalToolModelAttributes::rowCount(const QModelIndex& /*index*/) const {
     return items.size();
 }
 
-int CfgExternalToolModelAttributes::columnCount(const QModelIndex & /*index*/) const {
+int CfgExternalToolModelAttributes::columnCount(const QModelIndex& /*index*/) const {
     return COLUMNS_COUNT;
 }
 
-Qt::ItemFlags CfgExternalToolModelAttributes::flags(const QModelIndex & /*index*/) const{
+Qt::ItemFlags CfgExternalToolModelAttributes::flags(const QModelIndex& /*index*/) const {
     return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
 
-AttributeItem* CfgExternalToolModelAttributes::getItem(const QModelIndex &index) const {
+AttributeItem* CfgExternalToolModelAttributes::getItem(const QModelIndex& index) const {
     return items.at(index.row());
 }
 
@@ -563,117 +559,116 @@ QList<AttributeItem*> CfgExternalToolModelAttributes::getItems() const {
     return items;
 }
 
-QVariant CfgExternalToolModelAttributes::data(const QModelIndex &index, int role) const {
-    AttributeItem *item = getItem(index);
+QVariant CfgExternalToolModelAttributes::data(const QModelIndex& index, int role) const {
+    AttributeItem* item = getItem(index);
     int col = index.column();
 
     switch (role) {
-    case Qt::DisplayRole: // fallthrough
-    case Qt::ToolTipRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return item->getName();
-        case COLUMN_ID:
-            return item->getId();
-        case COLUMN_DATA_TYPE:
-            return typesDelegate->getDisplayValue(item->getDataType());
-        case COLUMN_DEFAULT_VALUE:
-            return item->delegateForDefaultValues->getDisplayValue(item->getDefaultValue());
-        case COLUMN_DESCRIPTION:
-            return item->getDescription();
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
-        }
-    case DelegateRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForNames);
-        case COLUMN_ID:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForIds);
-        case COLUMN_DATA_TYPE:
-            return qVariantFromValue<PropertyDelegate*>(typesDelegate);
-        case COLUMN_DEFAULT_VALUE:
-            return qVariantFromValue<PropertyDelegate*>(item->delegateForDefaultValues);
+        case Qt::DisplayRole:  // fallthrough
+        case Qt::ToolTipRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return item->getName();
+                case COLUMN_ID:
+                    return item->getId();
+                case COLUMN_DATA_TYPE:
+                    return typesDelegate->getDisplayValue(item->getDataType());
+                case COLUMN_DEFAULT_VALUE:
+                    return item->delegateForDefaultValues->getDisplayValue(item->getDefaultValue());
+                case COLUMN_DESCRIPTION:
+                    return item->getDescription();
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
+                    return QVariant();
+            }
+        case DelegateRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForNames);
+                case COLUMN_ID:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForIds);
+                case COLUMN_DATA_TYPE:
+                    return qVariantFromValue<PropertyDelegate*>(typesDelegate);
+                case COLUMN_DEFAULT_VALUE:
+                    return qVariantFromValue<PropertyDelegate*>(item->delegateForDefaultValues);
+                default:
+                    return QVariant();
+            }
+        case Qt::EditRole:  // fallthrough
+        case ConfigurationEditor::ItemValueRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    return item->getName();
+                case COLUMN_ID:
+                    return item->getId();
+                case COLUMN_DATA_TYPE:
+                    return item->getDataType();
+                case COLUMN_DEFAULT_VALUE:
+                    return item->getDefaultValue();
+                case COLUMN_DESCRIPTION:
+                    return item->getDescription();
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
+                    return QVariant();
+            }
         default:
             return QVariant();
-        }
-    case Qt::EditRole: // fallthrough
-    case ConfigurationEditor::ItemValueRole:
-        switch (col) {
-        case COLUMN_NAME:
-            return item->getName();
-        case COLUMN_ID:
-            return item->getId();
-        case COLUMN_DATA_TYPE:
-            return item->getDataType();
-        case COLUMN_DEFAULT_VALUE:
-            return item->getDefaultValue();
-        case COLUMN_DESCRIPTION:
-            return item->getDescription();
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
-        }
-    default:
-        return QVariant();
     }
 }
 
-bool CfgExternalToolModelAttributes::setData(const QModelIndex &index, const QVariant &value, int role) {
+bool CfgExternalToolModelAttributes::setData(const QModelIndex& index, const QVariant& value, int role) {
     int col = index.column();
-    AttributeItem * item = getItem(index);
+    AttributeItem* item = getItem(index);
     switch (role) {
-    case Qt::EditRole: // fallthrough
-    case ConfigurationEditor::ItemValueRole:
-        switch (col) {
-        case COLUMN_NAME:
-            if (item->getName() != value.toString()) {
-                const QString oldGeneratedId = WorkflowUtils::generateIdFromName(item->getName());
-                const bool wasIdEditedByUser = (oldGeneratedId != item->getId());
-                item->setName(value.toString());
-                if (!wasIdEditedByUser) {
-                    item->setId(WorkflowUtils::generateIdFromName(item->getName()));
+        case Qt::EditRole:  // fallthrough
+        case ConfigurationEditor::ItemValueRole:
+            switch (col) {
+                case COLUMN_NAME:
+                    if (item->getName() != value.toString()) {
+                        const QString oldGeneratedId = WorkflowUtils::generateIdFromName(item->getName());
+                        const bool wasIdEditedByUser = (oldGeneratedId != item->getId());
+                        item->setName(value.toString());
+                        if (!wasIdEditedByUser) {
+                            item->setId(WorkflowUtils::generateIdFromName(item->getName()));
+                        }
+                    }
+                    break;
+                case COLUMN_ID:
+                    if (item->getId() != value.toString()) {
+                        item->setId(value.toString());
+                    }
+                    break;
+                case COLUMN_DATA_TYPE: {
+                    QString newType = value.toString();
+                    if (item->getDataType() != newType) {
+                        if (!newType.isEmpty()) {
+                            item->setDataType(newType);
+                            changeDefaultValueDelegate(newType, item);
+                        }
+                    }
+                    break;
                 }
-            }
-            break;
-        case COLUMN_ID:
-            if (item->getId() != value.toString()) {
-                item->setId(value.toString());
-            }
-            break;
-        case COLUMN_DATA_TYPE: {
-            QString newType = value.toString();
-            if (item->getDataType() != newType) {
-                if (!newType.isEmpty()) {
-                    item->setDataType(newType);
-                    changeDefaultValueDelegate(newType, item);
+                case COLUMN_DEFAULT_VALUE: {
+                    if (item->getDefaultValue() != value.toString()) {
+                        item->setDefaultValue(value.toString());
+                    }
+                    break;
                 }
+                case COLUMN_DESCRIPTION:
+                    if (item->getDescription() != value.toString()) {
+                        item->setDescription(value.toString());
+                    }
+                    break;
+                default:
+                    // do nothing, inaccessible code
+                    Q_ASSERT(false);
             }
-            break;
-        }
-        case COLUMN_DEFAULT_VALUE: {
-            if (item->getDefaultValue() != value.toString()) {
-                item->setDefaultValue(value.toString());
-            }
-            break;
-        }
-        case COLUMN_DESCRIPTION:
-            if (item->getDescription() != value.toString()) {
-                item->setDescription(value.toString());
-            }
-            break;
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-        }
 
-        emit dataChanged(index, index);
-        break;
-    default:
-        ; // do nothing
+            emit dataChanged(index, index);
+            break;
+        default:;  // do nothing
     }
     return true;
 }
@@ -681,28 +676,28 @@ bool CfgExternalToolModelAttributes::setData(const QModelIndex &index, const QVa
 QVariant CfgExternalToolModelAttributes::headerData(int section, Qt::Orientation orientation, int role) const {
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch (section) {
-        case COLUMN_NAME:
-            return tr("Display name");
-        case COLUMN_ID:
-            return tr("Argument name");
-        case COLUMN_DATA_TYPE:
-            return tr("Type");
-        case COLUMN_DEFAULT_VALUE:
-            return tr("Default value");
-        case COLUMN_DESCRIPTION:
-            return tr("Description");
-        default:
-            // do nothing, inaccessible code
-            Q_ASSERT(false);
-            return QVariant();
+            case COLUMN_NAME:
+                return tr("Display name");
+            case COLUMN_ID:
+                return tr("Argument name");
+            case COLUMN_DATA_TYPE:
+                return tr("Type");
+            case COLUMN_DEFAULT_VALUE:
+                return tr("Default value");
+            case COLUMN_DESCRIPTION:
+                return tr("Description");
+            default:
+                // do nothing, inaccessible code
+                Q_ASSERT(false);
+                return QVariant();
         }
     }
     return QVariant();
 }
 
-bool CfgExternalToolModelAttributes::insertRows(int /*row*/, int /*count*/, const QModelIndex & parent)  {
+bool CfgExternalToolModelAttributes::insertRows(int /*row*/, int /*count*/, const QModelIndex& parent) {
     beginInsertRows(parent, items.size(), items.size());
-    AttributeItem *newItem = new AttributeItem();
+    AttributeItem* newItem = new AttributeItem();
     newItem->delegateForNames = new LineEditWithValidatorDelegate(WorkflowEntityValidator::ACCEPTABLE_NAME);
     newItem->delegateForIds = new LineEditWithValidatorDelegate(WorkflowEntityValidator::ACCEPTABLE_ID);
     newItem->setDataType(AttributeConfig::STRING_TYPE);
@@ -712,7 +707,7 @@ bool CfgExternalToolModelAttributes::insertRows(int /*row*/, int /*count*/, cons
     return true;
 }
 
-bool CfgExternalToolModelAttributes::removeRows(int row, int count, const QModelIndex & parent) {
+bool CfgExternalToolModelAttributes::removeRows(int row, int count, const QModelIndex& parent) {
     CHECK(0 <= row && row < items.size(), false);
     CHECK(0 <= row + count - 1 && row + count - 1 < items.size(), false);
     CHECK(0 < count, false);
@@ -725,4 +720,4 @@ bool CfgExternalToolModelAttributes::removeRows(int row, int count, const QModel
     return true;
 }
 
-} // U2
+}  // namespace U2
