@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -19,8 +19,7 @@
  * MA 02110-1301, USA.
  */
 
-#ifndef _MARK_SEQUENCE_WORKER_H_
-#define _MARK_SEQUENCE_WORKER_H_
+#pragma once
 
 #include <U2Lang/LocalDomain.h>
 #include <U2Lang/WorkflowUtils.h>
@@ -31,12 +30,14 @@ namespace LocalWorkflow {
 class MarkSequencePrompter : public PrompterBase<MarkSequencePrompter> {
     Q_OBJECT
 public:
-    MarkSequencePrompter(Actor *p = NULL) : PrompterBase<MarkSequencePrompter>(p) {}
+    MarkSequencePrompter(Actor* p = nullptr)
+        : PrompterBase<MarkSequencePrompter>(p) {
+    }
 
 protected:
     QString composeRichDoc();
 
-}; // MarkSequencePrompter
+};  // MarkSequencePrompter
 
 class MarkSequenceWorker : public BaseWorker {
     Q_OBJECT
@@ -44,30 +45,31 @@ public:
     static QMap<QString, QString> cuteAlIdNames;
 
 public:
-    MarkSequenceWorker(Actor *p);
+    MarkSequenceWorker(Actor* p);
 
     virtual void init();
-    virtual Task *tick();
-    virtual void cleanup() {}
+    virtual Task* tick();
+    virtual void cleanup() {
+    }
 
 private:
-    IntegralBus *inChannel;
-    IntegralBus *outChannel;
+    IntegralBus* inChannel;
+    IntegralBus* outChannel;
     DataTypePtr mtype;
 
-}; // MarkSequenceWorker
+};  // MarkSequenceWorker
 
 class MarkSequenceWorkerFactory : public DomainFactory {
 public:
     static const QString ACTOR_ID;
 
-    MarkSequenceWorkerFactory() : DomainFactory(ACTOR_ID) {}
+    MarkSequenceWorkerFactory()
+        : DomainFactory(ACTOR_ID) {
+    }
     static void init();
-    virtual Worker *createWorker(Actor *a);
+    virtual Worker* createWorker(Actor* a);
 
-}; // MarkSequenceWorkerFactory
+};  // MarkSequenceWorkerFactory
 
-} // LocalWorkflow
-} // U2
-
-#endif // _MARK_SEQUENCE_WORKER_H_
+}  // namespace LocalWorkflow
+}  // namespace U2
